@@ -17,6 +17,7 @@ public:
     explicit Playlist(QWidget *parent = 0);
     QStringList getPlaylists();
     void addToPlaylist(QString playlist, QString article);
+    void setMode(QString mode);
     ~Playlist();
 
 private slots:
@@ -26,11 +27,13 @@ signals:
     void articleSelected(QTreeWidgetItem *item, int column);
     void playlistSelected(QList<QTreeWidgetItem *> items, int column);
 
+
 private:
     Ui::Playlist *ui;
     QMap<QString, QString> *titles;
     Playlists *playlistlist;
     void updateList();
+    QString mode;
 };
 
 #endif // PLAYLIST_H
